From deed4e980f52e8a1cb259cd3faf2f3206a0c7513 Mon Sep 17 00:00:00 2001
From: Antonio Terceiro <terceiro@debian.org>
Date: Thu, 28 May 2015 10:03:09 -0300
Subject: [PATCH] @builddeps@: filter out build profiles syntax

---
 lib/testdesc.py | 10 ++++++++--
 tests/testdesc  | 11 +++++++++++
 2 files changed, 19 insertions(+), 2 deletions(-)

diff --git a/lib/testdesc.py b/lib/testdesc.py
index 12e4267..2e81c59 100644
--- a/lib/testdesc.py
+++ b/lib/testdesc.py
@@ -230,15 +230,21 @@ def _debian_packages_from_source(srcdir):
 
 def _debian_build_deps_from_source(srcdir):
     deps = []
+    def normalize_build_dependency(dep):
+        """
+        Removes build profiles syntax, plus any leading/trailing whitespace
+        """
+        return re.sub('<[^<>]*>', '', dep).strip()
+
     for st in parse_rfc822(os.path.join(srcdir, 'debian/control')):
         if 'Build-depends' in st:
             for d in st['Build-depends'].split(','):
-                dp = d.strip()
+                dp = normalize_build_dependency(d)
                 if dp:
                     deps.append(dp)
         if 'Build-depends-indep' in st:
             for d in st['Build-depends-indep'].split(','):
-                dp = d.strip()
+                dp = normalize_build_dependency(d)
                 if dp:
                     deps.append(dp)
     # @builddeps@ should always imply build-essential
diff --git a/tests/testdesc b/tests/testdesc
index cf059a0..9665d47 100755
--- a/tests/testdesc
+++ b/tests/testdesc
@@ -326,6 +326,17 @@ class Debian(unittest.TestCase):
                                          'bdi1', 'build-essential', 'foo (>= 7)'])
         self.assertFalse(skipped)
 
+    def test_builddeps_with_build_profiles(self):
+        (ts, skipped) = self.call_parse(
+            'Tests: t\nDepends: @, @builddeps@',
+            'Source: nums\nBuild-Depends: bd1, bd2 <!nocheck>\n'
+            '\n'
+            'Package: one\nArchitecture: any')
+        self.assertEqual(ts[0].depends, ['one (>= 0~)', 'bd1', 'bd2',
+                                         'build-essential'])
+        self.assertFalse(skipped)
+
+
     def test_complex_deps(self):
         '''complex test dependencies'''
 
-- 
2.1.4

